==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/urls_etendues/lang/urls_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Aktualizovať všetky URL',
	'actualiser_toutes_explication' => 'Vous pouvez recalculer les URLs.
		Si une URL a changé, une nouvelle entrée sera créée (sans perdre les URLs déjà
		présentes et sans affecter les URLs définies manuellement.', # NEW

	// B
	'bouton_supprimer_url' => 'Odstrániť túto URL',

	// E
	'erreur_arbo_2_segments_max' => 'Pre objekt nemôžete použiť viac ako dve zložky adresy',
	'erreur_config_url_forcee' => 'Nastavenia internetových adries sú uložené v súbore <tt>mes_options.php</tt>.',
	'explication_editer' => 'Pokročilé riadenie internetových adries vám umožňuje upravovať internetové adresy (URL) redakčných stránok každého objektu a spravovať históriu ich vývoja.',

	// I
	'icone_configurer_urls' => 'Nastaviť URL',
	'icone_controler_urls' => 'Zmysluplné adresy',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Objekt',

	// L
	'label_tri_date' => 'Dátum',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nová URL',
	'label_url_minuscules_0' => 'Veľké/malé písmená ako v nadpise',
	'label_url_minuscules_1' => 'V URL používať malé písmená',
	'label_url_permanente' => 'Zamknúť túto URL (žiadne aktualizácie po úprave objektu)',
	'label_url_sep_id' => 'Znak na oddelenie čísla, ktoré sa pridá v prípade duplikátu',
	'label_urls_activer_controle_oui' => 'Aktivovať pokročilé riadenie internetových adries',
	'label_urls_nb_max_car' => 'Maximálny počet znakov',
	'label_urls_nb_min_car' => 'Minimálny počet znakov',
	'liberer_url' => 'Potvrdiť',
	'liste_des_urls' => 'Všetky URL',

	// T
	'texte_type_urls' => 'Na tomto mieste si môžete vybrať spôsob, akým sa budú vytvárať adresy stránok.',
	'texte_type_urls_attention' => 'Varovanie: toto nastavenie bude fungovať, iba ak je súbor @htaccess@ správne nainštalovaný v koreňovom adresári stránky.',
	'texte_urls_nb_max_car' => 'Ak bude názov dlhší, bude skrátený.',
	'texte_urls_nb_min_car' => 'Ak bude názov kratší, použije sa jeho identifikačné číslo.',
	'titre_gestion_des_urls' => 'Riadenie internetových adries',
	'titre_type_arbo' => 'Stromovité URL',
	'titre_type_html' => 'URL ako objekty HTML',
	'titre_type_libres' => 'Nezávislé URL',
	'titre_type_page' => 'URL podľa stránky',
	'titre_type_propres' => 'Vlastné URL',
	'titre_type_propres2' => 'Vlastné URL +<tt>.html</tt>',
	'titre_type_propres_qs' => 'Vlastné URL v reťazci požiadavky',
	'titre_type_simple' => 'Jednoduché URL',
	'titre_type_standard' => 'Historické URL',
	'titre_type_urls' => 'Typ internetových adries',
	'tout_voir' => 'Zobraziť všetky URL',

	// U
	'url_ajout_impossible' => 'Došlo k chybe. Táto URL sa nedá zaregistrovať.',
	'url_ajoutee' => 'Internetová adresa bola pridaná',

	// V
	'verifier_url_nettoyee' => 'URL bola opravená, môžete ju pred uložením skontrolovať.',
	'verrouiller_url' => 'Zamknúť'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/urls_etendues/lang/urls_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Aktualizovať všetky URL',
	'actualiser_toutes_explication' => 'Môžete obnoviť adresy URL.
		Ak sa nejaká adresa zmenila, bude vytvorený nový záznam (bez toho, aby ste stratili zaznamenané adresy URL a bez vplyvu na adresy zadané ručne.',

	// B
	'bouton_supprimer_url' => 'Odstrániť túto URL',

	// E
	'erreur_arbo_2_segments_max' => 'Pre objekt nemôžete použiť viac ako dve zložky adresy',
	'erreur_config_url_forcee' => 'Nastavenia internetových adries sú uložené v súbore <tt>mes_options.php</tt>.',
	'explication_editer' => 'Pokročilé riadenie internetových adries vám umožňuje upravovať internetové adresy (URL) redakčných stránok každého objektu a spravovať históriu ich vývoja.',

	// I
	'icone_configurer_urls' => 'Nastaviť URL',
	'icone_controler_urls' => 'Zmysluplné adresy',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Objekt',

	// L
	'label_tri_date' => 'Dátum',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nová URL',
	'label_url_minuscules_0' => 'Veľké/malé písmená ako v nadpise',
	'label_url_minuscules_1' => 'V URL používať malé písmená',
	'label_url_permanente' => 'Zamknúť túto URL (žiadne aktualizácie po úprave objektu)',
	'label_url_sep_id' => 'Znak na oddelenie čísla, ktoré sa pridá v prípade duplikátu',
	'label_urls_activer_controle_oui' => 'Aktivovať pokročilé riadenie internetových adries',
	'label_urls_nb_max_car' => 'Maximálny počet znakov',
	'label_urls_nb_min_car' => 'Minimálny počet znakov',
	'liberer_url' => 'Potvrdiť',
	'liste_des_urls' => 'Všetky URL',

	// T
	'texte_type_urls' => 'Na tomto mieste si môžete vybrať spôsob, akým sa budú vytvárať adresy stránok.',
	'texte_type_urls_attention' => 'Varovanie: toto nastavenie bude fungovať, iba ak je súbor @htaccess@ správne nainštalovaný v koreňovom adresári stránky.',
	'texte_urls_nb_max_car' => 'Ak bude názov dlhší, bude skrátený.',
	'texte_urls_nb_min_car' => 'Ak bude názov kratší, použije sa jeho identifikačné číslo.',
	'titre_gestion_des_urls' => 'Riadenie internetových adries',
	'titre_type_arbo' => 'Stromovité URL',
	'titre_type_html' => 'URL ako objekty HTML',
	'titre_type_libres' => 'Nezávislé URL',
	'titre_type_page' => 'URL podľa stránky',
	'titre_type_propres' => 'Vlastné URL',
	'titre_type_propres2' => 'Vlastné URL +<tt>.html</tt>',
	'titre_type_propres_qs' => 'Vlastné URL v reťazci požiadavky',
	'titre_type_simple' => 'Jednoduché URL',
	'titre_type_standard' => 'Historické URL',
	'titre_type_urls' => 'Typ internetových adries',
	'tout_voir' => 'Zobraziť všetky URL',

	// U
	'url_ajout_impossible' => 'Došlo k chybe. Táto URL sa nedá zaregistrovať.',
	'url_ajoutee' => 'Internetová adresa bola pridaná',

	// V
	'verifier_url_nettoyee' => 'URL bola opravená, môžete ju pred uložením skontrolovať.',
	'verrouiller_url' => 'Zamknúť'
);

?>
